# rmtoo-topic-format

NAME
FILE FORMAT
KEYS
KEY ’Name’
KEY ’Text’
KEY ’IncludeRequirements’
KEY ’SubTopic’
EXAMPLE
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-topic-format - requirements management tool: topic format

## FILE FORMAT

Each topic must be in its own file. The filename must end in ’.tic’. Only ASCII characters are allowed. Each line must at maximum 80 characters long.

The topic must be written as a set of ’key: value’ pairs. A value is extended if the first column of a line is a space.

A key can exists multiple times in a topic data file. Order matters.

## KEYS

The following keys with the described syntax and semantic exists:

## KEY ’Name’

The value is the name of the topic. This is used as a chapter headline in the output document.

## KEY ’Text’

The text value will be copied into the output document.

## KEY ’IncludeRequirements’

This is the position where all the requirements are inserted in the output document. The value must be the string ’full’.

## KEY ’SubTopic’

The value of the subtopic must be the id of another topic. This topic is inserted at the point of occurance.

## EXAMPLE

Note that the following example has some initial indent resulting from the word processing program. The keywords must start at the first column. Additional lines must have a space in column one.

Name: Example Topic
Text: This is an indrocution to the Example Topic.
SubTopic: SomeMoreDetails
Text: The text appears between the SomeMoreDetails
topic and the requirements themselves.
IncludeRequirements: full
Text: The text after the requirements.

## SEE ALSO

rmtoo(7) - overview over rmtoo requirements management tool. All references can be found there.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later